==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_EMAIL","Emaila");

define("_RE","Erantzuna");
define("_SUBJECT","Gaia");
define("_PRIVATEMESSAGES","Zure mezu pribatuak");
define("_CHECKALL","Dena ikusi");
define("_FROM","Nork bidalita");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Ez daukazu mezurik");
define("_NOTREAD","Irakurri gabe");
define("_MSGSTATUS","Mezuaren egoera");
define("_PRIVATEMESSAGE","Mezu Pribatua");
define("_INDEX","Indizea");
define("_SENT","noiz bidalia");
define("_PREVIOUSMESSAGE","Aurreko Mezua");
define("_NEXTMESSAGE","Hurrengo Mezua");
define("_PROFILE","Profila");
define("_ABOUTPOSTING","Bidalketaren inguruan");
define("_ALLREGCANPOST","erregistratuko Sistema-kideek mezu pribatuak bidali dezakete");
define("_TO","Norentzat");
define("_MESSAGEICON","Mezuaren Ikonoa");
define("_MESSAGE","Mezua");
define("_HTML","HTML");
define("_PMON","bai");
define("_PMOFF","ez");
define("_BBCODE","BB-kodea");
define("_WROTE","idatzi zuen");
define("_OPTIONS","Aukerak");
define("_HTMLDISSABLE","HTML kodea desaktibatu bidalketa honetan");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBKodea</i></a> kodea desaktibatu bidalketa honetan");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>Smilie-ak</i></a> kodea desaktibatu bidalketa honetan");
define("_CANCELREPLY","Erantzuna deuseztatu");
define("_CANCELSEND","Bidalketa deuseztatu");
define("_CLEAR","Garbitu");
define("_SUBMIT","Bidali");
define("_USERNOTINDB","Sistema-kidea ez da aurkitzen datubasean");
define("_CHECKNAMEANDTRY","Mesedez, zuzendu izena eta saiatu berriz");
define("_MSGPOSTED","Zure mezua bidali da.");
define("_RETURNTOPMSG","Egin klik hemen zure mezu pribatuak gaurkotzeko.");
define("_MSGDELETED","Zure mezuak ezabatu dira.");
define("_BBGO","doa");
define("_BBNEWPMSG","Mezu berriak");
define("_BBNONEWPMSG","Ez dago mezu berririk");
define("_BBTOTALPMSG","Mezuak guztira,");
define("_BBEMPTYPMSG","Ez dago mezurik");
define("_BBLOGIN","Konektatu zure mezu pribatuak begiratzeko");
define("_BBPMSG","Mezu pribatuak");
define("_BBINBOX","Sarrera buzoia");
define("_BBSELECTFORUM","Aukeratu foro bat");
define("_BBNOFORUM","Ez dago foro gehiago");
define("_BBBANNED","Debekatuta");
define("_CLICKSMILEBUTTONS","Klik egin mezuan txertatu nahi duzun smilie-aren gainean:");
define("_CLICKCODEBUTTONS","Klik egin mezuan txertatu nahi duzun BBCode-aren gainean:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_EMAIL","Emaila");

define("_RE","Erantzuna");
define("_SUBJECT","Gaia");
define("_PRIVATEMESSAGES","Zure mezu pribatuak");
define("_CHECKALL","Dena ikusi");
define("_FROM","Nork bidalita");
define("_DATE","Data");
define("_DONTHAVEMESSAGES","Ez daukazu mezurik");
define("_NOTREAD","Irakurri gabe");
define("_MSGSTATUS","Mezuaren egoera");
define("_PRIVATEMESSAGE","Mezu Pribatua");
define("_INDEX","Indizea");
define("_SENT","noiz bidalia");
define("_PREVIOUSMESSAGE","Aurreko Mezua");
define("_NEXTMESSAGE","Hurrengo Mezua");
define("_PROFILE","Profila");
define("_ABOUTPOSTING","Bidalketaren inguruan");
define("_ALLREGCANPOST","erregistratuko Sistema-kideek mezu pribatuak bidali dezakete");
define("_TO","Norentzat");
define("_MESSAGEICON","Mezuaren Ikonoa");
define("_MESSAGE","Mezua");
define("_HTML","HTML");
define("_PMON","bai");
define("_PMOFF","ez");
define("_BBCODE","BB-kodea");
define("_WROTE","idatzi zuen");
define("_OPTIONS","Aukerak");
define("_HTMLDISSABLE","HTML kodea desaktibatu bidalketa honetan");
define("_BBCODEDISSABLE","<a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBKodea</i></a> kodea desaktibatu bidalketa honetan");
define("_SMILEDISSABLE","<a href=\"bb_smilies.php\" target=\"_blank\"><i>Smilie-ak</i></a> kodea desaktibatu bidalketa honetan");
define("_CANCELREPLY","Erantzuna deuseztatu");
define("_CANCELSEND","Bidalketa deuseztatu");
define("_CLEAR","Garbitu");
define("_SUBMIT","Bidali");
define("_USERNOTINDB","Sistema-kidea ez da aurkitzen datubasean");
define("_CHECKNAMEANDTRY","Mesedez, zuzendu izena eta saiatu berriz");
define("_MSGPOSTED","Zure mezua bidali da.");
define("_RETURNTOPMSG","Egin klik hemen zure mezu pribatuak gaurkotzeko.");
define("_MSGDELETED","Zure mezuak ezabatu dira.");
define("_BBGO","doa");
define("_BBNEWPMSG","Mezu berriak");
define("_BBNONEWPMSG","Ez dago mezu berririk");
define("_BBTOTALPMSG","Mezuak guztira,");
define("_BBEMPTYPMSG","Ez dago mezurik");
define("_BBLOGIN","Konektatu zure mezu pribatuak begiratzeko");
define("_BBPMSG","Mezu pribatuak");
define("_BBINBOX","Sarrera buzoia");
define("_BBSELECTFORUM","Aukeratu foro bat");
define("_BBNOFORUM","Ez dago foro gehiago");
define("_BBBANNED","Debekatuta");
define("_CLICKSMILEBUTTONS","Klik egin mezuan txertatu nahi duzun smilie-aren gainean:");
define("_CLICKCODEBUTTONS","Klik egin mezuan txertatu nahi duzun BBCode-aren gainean:");


?>
